==> tagcoll_1.6.3-1.tar.gz: tagcoll-1.6.3/tagcoll/tagexpr/TagexprParser.cc <==
/*
 * Parser for tag expressions
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#if __GNUC__ < 3
#define _GNU_SOURCE
#endif

#include "TagexprParser.h"
#include <tagcoll/Exception.h>
#include <stdio.h>
#include <errno.h>

using namespace std;
using namespace Tagcoll;

TagexprParser* TagexprParser::_instance = 0;

TagexprParser* TagexprParser::instance()
{
	if (! _instance)
		_instance = new TagexprParser();
	return _instance;
}

extern FILE* yyin;
extern int yyparse();
extern int yydebug;

Expression Tagcoll::TagexprParser::parse(const std::string& buf)
{
	if (buf.empty())
		return result = Expression();

	FILE* in = fmemopen((void*)buf.data(), buf.size(), "r");
	if (in == 0)
		throw SystemException(errno, "invoking fmemopen on `"+buf+"'");

	errorMessage = string();
	yyin = in;
//	yydebug = 1;

	if (yyparse() == 0)
	{
		fclose(in);
		return result;
	}
	else
	{
		fclose(in);
		throw ConsistencyCheckException(errorMessage);
	}
}

// vim:set ts=4 sw=4:

==> tagcoll2_2.0.11.orig.tar.gz: tagcoll2-2.0.11/tagcoll/tagexpr/TagexprParser.cc <==
/*
 * Parser for tag expressions
 *
 * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */

#if __GNUC__ < 3
#define _GNU_SOURCE
#endif

#include "TagexprParser.h"
#include <wibble/exception.h>
#include <stdio.h>
#include <errno.h>

// using namespace std;
using namespace wibble;
using namespace tagcoll;

TagexprParser* TagexprParser::_instance = 0;

TagexprParser* TagexprParser::instance()
{
	if (! _instance)
		_instance = new TagexprParser();
	return _instance;
}

extern FILE* yyin;
extern int yyparse();
extern int yydebug;

Expression tagcoll::TagexprParser::parse(const std::string& buf)
{
	if (buf.empty())
		return result = Expression();

	FILE* in = fmemopen((void*)buf.data(), buf.size(), "r");
	if (in == 0)
		throw wibble::exception::System("invoking fmemopen on \""+buf+"\"");

	errorMessage = std::string();
	yyin = in;
//	yydebug = 1;

	if (yyparse() == 0)
	{
		fclose(in);
		return result;
	}
	else
	{
		fclose(in);
		throw wibble::exception::Consistency("parsing buffer \"" + buf + "\"", errorMessage);
	}
}

// vim:set ts=4 sw=4:
